MAL Parser
==========

Library to parse `MyAnimeList <http://myanimelist.net>`_ pages, it extracts
more than the un-official API

It can parse both Manga and Anime.

Help and stuff
--------------
https://github.com/JohnDoee (there is an email here)

Examples
--------
https://github.com/JohnDoee/malparser/blob/master/myanimelist/README.md

License
-------
See LICENSE
